@@ -8,16 +8,12 @@
 #define WAYLANDOUTPUTMANAGEMENT_H
 
 #include "qwayland-kde-output-management-v2.h"
-#include "qwayland-kde-output-order-v1.h"
 
 #include <QObject>
 #include <QSize>
 
 namespace KScreen
 {
-class WaylandConfig;
-class WaylandOutputDevice;
-
 class WaylandOutputConfiguration : public QObject, public QtWayland::kde_output_configuration_v2
 {
     Q_OBJECT
@@ -42,25 +38,6 @@ public:
     WaylandOutputConfiguration *createConfiguration();
 };
 
-class WaylandOutputOrder : public QObject, public QtWayland::kde_output_order_v1
-{
-    Q_OBJECT
-public:
-    WaylandOutputOrder(struct ::wl_registry *registry, int id, int version);
-    ~WaylandOutputOrder();
-
-    QVector<QString> order() const;
-
-Q_SIGNALS:
-    void outputOrderChanged(const QVector<QString> &outputs);
-
-private:
-    void kde_output_order_v1_output(const QString &output_name) override;
-    void kde_output_order_v1_done() override;
-
-    QVector<QString> m_outputOrder;
-    QVector<QString> m_pendingOutputOrder;
-};
 }
 
 #endif // WAYLANDOUTPUTMANAGEMENT_H
